"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deploymentTargetsOperationCommand = void 0;
const config_sets_1 = require("@takomo/config-sets");
const core_1 = require("@takomo/core");
const deployment_targets_context_1 = require("@takomo/deployment-targets-context");
const deployment_targets_schema_1 = require("@takomo/deployment-targets-schema");
const stacks_schema_1 = require("@takomo/stacks-schema");
const util_1 = require("@takomo/util");
const joi_1 = __importDefault(require("joi"));
const plan_1 = require("./plan");
const inputSchema = (regions) => {
    const { commandPath } = stacks_schema_1.createStacksSchemas({ regions });
    const { configSetName } = config_sets_1.createConfigSetsSchemas({ regions });
    const { deploymentGroupPath, deploymentTargetNamePattern, label } = deployment_targets_schema_1.createDeploymentTargetsSchemas({ regions });
    return joi_1.default.object({
        groups: joi_1.default.array().items(deploymentGroupPath).unique(),
        targets: joi_1.default.array().items(deploymentTargetNamePattern).unique(),
        labels: joi_1.default.array().items(label).unique(),
        concurrentTargets: joi_1.default.number().min(1).max(50),
        configSet: configSetName,
        commandPath,
    }).unknown(true);
};
const validateFeatureFlags = (ctx, input) => {
    if (input.operation === "undeploy" &&
        input.configSetType === "standard" &&
        !ctx.projectConfig.features.deploymentTargetsUndeploy) {
        throw new core_1.FeatureDisabledError("deploymentTargetsUndeploy");
    }
    if (input.operation === "undeploy" &&
        input.configSetType === "bootstrap" &&
        !ctx.projectConfig.features.deploymentTargetsTearDown) {
        throw new core_1.FeatureDisabledError("deploymentTargetsTearDown");
    }
};
const deploymentTargetsOperationCommand = async ({ ctx, input, configRepository, io, credentialManager, }) => util_1.validateInput(inputSchema(ctx.regions), input)
    .then(() => {
    validateFeatureFlags(ctx, input);
    return deployment_targets_context_1.createDeploymentTargetsContext({
        ctx,
        configRepository,
        credentialManager,
        logger: io,
    });
})
    .then((ctx) => plan_1.planDeployment({
    ctx,
    input,
    io,
    timer: input.timer,
}))
    .then(io.printOutput);
exports.deploymentTargetsOperationCommand = deploymentTargetsOperationCommand;
//# sourceMappingURL=command.js.map