"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.confirmOperation = void 0;
const process_1 = require("./process");
/**
 * @hidden
 */
const confirmOperation = async (holder) => {
    const { io, timer, plan, ctx, input } = holder;
    if (ctx.autoConfirmEnabled) {
        return process_1.processOperation(holder);
    }
    const answer = await io.confirmOperation(plan);
    switch (answer) {
        case "CANCEL":
            timer.stop();
            return {
                results: [],
                outputFormat: input.outputFormat,
                message: "Cancelled",
                status: "CANCELLED",
                success: false,
                timer,
            };
        case "CONTINUE_AND_REVIEW":
            return process_1.processOperation({
                ...holder,
                input: { ...holder.input, concurrentTargets: 1 },
            });
        case "CONTINUE_NO_REVIEW":
            return process_1.processOperation({
                ...holder,
                ctx: {
                    ...holder.ctx,
                    autoConfirmEnabled: true,
                    commandContext: {
                        ...holder.ctx.commandContext,
                        autoConfirmEnabled: true,
                    },
                },
            });
        default:
            throw new Error(`Unknown answer '${answer}'`);
    }
};
exports.confirmOperation = confirmOperation;
//# sourceMappingURL=confirm.js.map