"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processDeploymentTarget = void 0;
const core_1 = require("@takomo/core");
const config_set_1 = require("./config-set");
const getConfigSetsToProcess = (configSetType, target, configSetName) => {
    const configSetMatches = (cs) => configSetName === undefined || cs === configSetName;
    switch (configSetType) {
        case "bootstrap":
            return target.bootstrapConfigSets.filter(configSetMatches);
        case "standard":
            return target.configSets.filter(configSetMatches);
        default:
            throw new Error(`Unsupported config set type: ${configSetType}`);
    }
};
/**
 * @hidden
 */
const processDeploymentTarget = async (holder, group, target, timer, state) => {
    const { io, ctx, input } = holder;
    io.info(`Execute deployment target: ${target.name}`);
    const results = new Array();
    const configSetNames = getConfigSetsToProcess(input.configSetType, target, input.configSetName);
    for (const configSetName of configSetNames) {
        const configSet = ctx.getConfigSet(configSetName);
        const result = await config_set_1.processConfigSet(holder, group, target, configSet, timer.startChild(configSetName), state);
        results.push(result);
    }
    timer.stop();
    return {
        ...core_1.resolveCommandOutputBase(results),
        results,
        name: target.name,
        timer,
    };
};
exports.processDeploymentTarget = processDeploymentTarget;
//# sourceMappingURL=deployment-target.js.map