"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.planRun = void 0;
const util_1 = require("@takomo/util");
const ramda_1 = __importDefault(require("ramda"));
const plan_1 = require("../operation/plan");
const confirm_1 = require("./confirm");
const planRun = async ({ ctx, input, io, }) => {
    const { groups, targets, excludeTargets, labels, excludeLabels, timer } = input;
    if (groups.length > 0) {
        groups.forEach((groupPath) => {
            if (!ctx.hasDeploymentGroup(groupPath)) {
                throw new util_1.TakomoError(`Deployment group '${groupPath}' not found`);
            }
        });
    }
    const deploymentGroupsToLaunch = groups.length === 0
        ? ctx.rootDeploymentGroups
        : groups.reduce((collected, path) => {
            return [...collected, ctx.getDeploymentGroup(path)];
        }, new Array());
    const sortGroups = (a, b) => {
        const order = a.priority - b.priority;
        return order !== 0 ? order : a.name.localeCompare(b.name);
    };
    const groupsToLaunch = deploymentGroupsToLaunch
        .map((ou) => util_1.collectFromHierarchy(ou, (o) => o.children, {
        sortSiblings: sortGroups,
        filter: (o) => o.status === "active",
    }))
        .flat();
    const uniqueGroupsToLaunch = ramda_1.default.uniqBy(ramda_1.default.prop("path"), groupsToLaunch).filter((o) => o.status === "active");
    const targetNameMatchers = targets.map(plan_1.createDeploymentTargetNamePatternMatcher);
    const excludeTargetNameMatchers = excludeTargets.map(plan_1.createDeploymentTargetNamePatternMatcher);
    const targetNameMatches = (target) => (targetNameMatchers.length === 0 ||
        targetNameMatchers.some((m) => m(target))) &&
        (excludeTargetNameMatchers.length === 0 ||
            !excludeTargetNameMatchers.some((m) => m(target)));
    const labelMatches = (target) => (labels.length === 0 || target.labels.some((l) => labels.includes(l))) &&
        (excludeLabels.length === 0 ||
            !target.labels.some((l) => excludeLabels.includes(l)));
    const grs = uniqueGroupsToLaunch
        .map((ou) => {
        return {
            ...ou,
            targets: ou.targets.filter((a) => a.status === "active" && targetNameMatches(a) && labelMatches(a)),
        };
    })
        .filter((ou) => ou.targets.length > 0);
    const selectedTargets = grs.map((g) => g.targets).flat();
    if (selectedTargets.length === 0) {
        timer.stop();
        return {
            timer,
            success: true,
            status: "SKIPPED",
            message: "No targets",
            result: undefined,
            outputFormat: input.outputFormat,
        };
    }
    const listener = io.createDeploymentTargetsListener(selectedTargets.length);
    const plan = {
        groups: grs,
    };
    return confirm_1.confirmRun({ plan, io, ctx, input, listener });
};
exports.planRun = planRun;
//# sourceMappingURL=plan.js.map